#! /usr/bin/env python3

from glob import glob
from os import path
from pickle import Unpickler
from pprint import pprint

from PyFoam.Applications.AddCaseDataToDatabase import AddCaseDataToDatabase
from PyFoam.Basics.RunDatabase import RunDatabase

from calcRocketHeight import calcHeights, solutionToDataFrame

pattern = "bottleRocket_h=*bar"
dbName = "bottleRocketData.db"
pickleFile = "PyFoamRunner.compressibleInterFoam.analyzed/pickledData"

cases = glob(pattern)

print("Adding basics from {} cases".format(len(cases)))
AddCaseDataToDatabase(args=[dbName] + [path.join(c,pickleFile) for c in cases] + ["--create"])

db = RunDatabase(dbName)

for c in cases:
    print(f"Processing {c}")
    data = Unpickler(open(path.join(c,pickleFile), "rb")).load()
    runId = data["uniqueid"]
    pressure = data["parameters"]["initPressure"]
    height = data["parameters"]["initHeight"]
    print(f"  ID: {runId} p={pressure} h={height}")

    solNoDrag, solDrag = calcHeights(c)
    noDrag = solutionToDataFrame(solNoDrag)
    withDrag = solutionToDataFrame(solDrag)

    evaluations = {"noDrag" : { "hMax": noDrag.h.max(), "hMaxTime": noDrag.h.idxmax(),
                                "velMax": noDrag.vel.max(), "velMaxTime": noDrag.vel.idxmax(),
                                "hVelMax" : noDrag.h[noDrag.vel.idxmax()]},
                   "withDrag" : { "hMax": withDrag.h.max(), "hMaxTime": withDrag.h.idxmax(),
                                  "velMax": withDrag.vel.max(), "velMaxTime": withDrag.vel.idxmax(),
                                  "hVelMax" : withDrag.h[withDrag.vel.idxmax()]}}
    pprint(evaluations)
    db.modify(runId,{"evaluations": evaluations})
