#! /usr/bin/env python3

import sys
from os import path

from PyFoam.Applications.PrepareCase import PrepareCase
from PyFoam.Applications.CloneCase import CloneCase
from PyFoam.Applications.Runner import Runner
from PyFoam.RunDictionary.ParsedParameterFile import ParsedParameterFile

if len(sys.argv) != 3:
    print("Script needs 2 argument: <initial height> and <initial pressure>")
    sys.exit(1)

initHeight = float(sys.argv[1])
initPressure = float(sys.argv[2])

if initHeight < 0:
    print("Initial height should be bigger than 0")
    sys.exit(1)

if initPressure < 0:
    print("Initial pressure should be bigger than 0")
    sys.exit(1)

caseName = "bottleRocket_h={:.1f}cm_p={:.2f}bar".format(100*initHeight,
                                                        initPressure/1e5)

CloneCase(args=["bottleRocketTemplate",
                caseName])


setFields = ParsedParameterFile(path.join(caseName,"system","setFieldsDict"))
setFields["initPressure"] = initPressure
setFields["initHeight"] = initHeight
setFields.writeFile()

controlDict = ParsedParameterFile(path.join(caseName,"system","controlDict"),
                                  backup=True)
controlDict["writePrecision"] = 15
controlDict.writeFile()

PrepareCase(args=["--execute-in-case-directory",
                  caseName])

controlDict.restore()

Runner(args=["--progress",
             "--parameter=initPressure:{}".format(initPressure),
             "--parameter=initHeight:{}".format(initHeight),
             "auto",
             "-case", caseName])
